pub enum DeleteZoneError<T> {
Unauthorized,
NotFound,
Custom(T),
}Expand description
Represents an error that occured when deleting DNS zones using DeleteZone::delete_zone.
Providers can provide a custom error type (DeleteZone::CustomDeleteError) and return it using DeleteZoneError::Custom to extend the pool of well-defined errors.
Refer to the provider’s documentation for more information.
Variants
Indicates that the DNS provider is not authorized to execute this action.
NotFound
Indicates that there is no zone with the given ID.
Custom(T)
Provides a custom, provider-specific error of type T.