pub enum RetrieveZoneError<T> {
Unauthorized,
NotFound,
Custom(T),
}Expand description
Represents an error that occured when retrieving DNS zones using Provider::list_zones or Provider::get_zone.
Providers can provide a custom error type (Provider::CustomRetrieveError) and return it using RetrieveZoneError::Custom to extend the pool of well-defined errors.
Refer to the provider’s documentation for more information.
Variants
Indicates that the DNS provider is not authorized to execute this action.
NotFound
Indicates that there is no zone with the given ID.
Custom(T)
Provides a custom, provider-specific error of type T.