CreateZone

Trait CreateZone 

pub trait CreateZone: Provider {
    type CustomCreateError: Debug;

    // Required method
    fn create_zone(
        &self,
        domain: &str,
    ) -> impl Future<Output = Result<Self::Zone, CreateZoneError<Self::CustomCreateError>>>;
}
Represents a Provider that supports zone creation.

Required Associated Types

type CustomCreateError: Debug

The provider-specific custom zone creation error type used for CreateZoneError::Custom.
If no custom errors should be provided, use ().

Required Methods

fn create_zone( &self, domain: &str, ) -> impl Future<Output = Result<Self::Zone, CreateZoneError<Self::CustomCreateError>>>

Creates a new DNS zone with the given domain.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors