DeleteRecord

Trait DeleteRecord 

pub trait DeleteRecord: Zone {
    type CustomDeleteError: Debug;

    // Required method
    fn delete_record(
        &self,
        record_id: &str,
    ) -> impl Future<Output = Result<(), DeleteRecordError<Self::CustomDeleteError>>>;
}
Represents a Zone that supports record deletion.

Required Associated Types

type CustomDeleteError: Debug

The provider-specific custom record creation error type used for DeleteRecordError::Custom.
If no custom errors should be provided, use ().

Required Methods

fn delete_record( &self, record_id: &str, ) -> impl Future<Output = Result<(), DeleteRecordError<Self::CustomDeleteError>>>

Deletes a record by its ID.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors